Performs an action in a countdown timer dynamically in a Shiny app via server
logic. You can start, stop, reset, or bump time time (when the timer is
running) up or down. See countdown_shiny_example() for an example app
demonstrating the usage of countdown_action().
countdown_action(
id,
action = c("start", "stop", "reset", "bumpUp", "bumpDown"),
session = NULL
)Invisibly returns the id of the updated countdown timer(s).
A character vector with one or more id values for timers created
with countdown() or countdown_fullscreen(). Be sure to set the id
value when creating the timer.
The action to perform, one of "start", "stop", "reset",
"bumpUp", or "bumpDown".
The reactive session object for the current Shiny session.
In general, only required for expert or unusual use cases.
Other Shiny functions:
countdown_app(),
countdown_shiny_example(),
countdown_update()